.. django-require-license documentation master file

Overview
========

This is the documentation for `django-require-license`_ |release|, generated on |today|.


Developer Guide
---------------

.. toctree::
   :maxdepth: 1

   development


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _django-require-license: https://github.com/collab-project/django-require-license
